# ChatGPT <img src="https://github.com/acheong08/ChatGPT/blob/main/logo.png?raw=true" width="7%"></img>
[![PyPi](https://img.shields.io/pypi/v/revChatGPT.svg)](https://pypi.python.org/pypi/revChatGPT)
[![PyPi](https://img.shields.io/pypi/dm/revChatGPT.svg)](https://pypi.python.org/pypi/revChatGPT)

Reverse Engineered ChatGPT by OpenAI. Extensible for chatbots etc.

<sup>Connect with me on [Linkedin](https://www.linkedin.com/in/acheong08/) to support this project. I'm graduating high school soon and knowing some people might help my chances at finding employment.</sup>

## Need help?
Ask for help on our [Discord](https://discord.gg/RvBkdcYUrH)

# Notice 
> ### On the 12th of December 2022, OpenAI added Cloudflare protections to their API. Please refer to the new [wiki](https://github.com/acheong08/ChatGPT/wiki/Setup) for instructions
> > ### As of 13th of December 2022, a usable bypass has been made. Please update your versions as soon as possible. Delete your `config.json` and let the browser handle it. (Requires desktop environment)
> > > ### 14th of December 2022: The maintainer is sick. Repository updates might be delayed. Pull requests will still be reviewed

We are hoping for an official API to be released soon to avoid the need for bypassing Cloudflare.

# Instructions
Instructions have been moved to the [Wiki](https://github.com/acheong08/ChatGPT/wiki).

# Features
![image](https://user-images.githubusercontent.com/36258159/205534498-acc59484-c4b4-487d-89a7-d7b884af709b.png)
- No moderation
- Programmable.
- Async version
- Cookie based authentication

# Flaws
- No ARM support for email/password. Use session token authentication if on Raspberry Pi

# Help needed
- Document the new changes (Desktop / Server - In regards to Cloudflare)

# Awesome ChatGPT
[My list](https://github.com/stars/acheong08/lists/awesome-chatgpt)

If you have a cool project you want added to the list, open an issue.

# Disclaimers
This is not an official OpenAI product. This is a personal project and is not affiliated with OpenAI in any way. Don't sue me

# Credits
- [rawandahmad698](https://github.com/rawandahmad698) - Reverse engineering Auth0
- [FlorianREGAZ](https://github.com/FlorianREGAZ) - TLS client
- [PyRo1121](https://github.com/PyRo1121) - Linting
- [Harry-Jing](https://github.com/Harry-Jing) - Async support
- [Ukenn2112](https://github.com/Ukenn2112) - Documentation
- [aliferouss19](https://github.com/aliferouss19) - Logo
- [All other contributors](https://github.com/acheong08/ChatGPT/graphs/contributors)
